@@ -208,11 +208,12 @@ fn parse_import_assertions(asserts: Option<&ast::ObjectLit>) -> HashMap<String,
 #[cfg(test)]
 mod tests {
     use super::*;
+    use ast::EsVersion;
     use swc_common::{
         comments::{Comment, CommentKind, SingleThreadedComments},
         BytePos, FileName, Span, SyntaxContext,
     };
-    use swc_ecma_parser::{lexer::Lexer, JscTarget, Parser, StringInput, Syntax, TsConfig};
+    use swc_ecma_parser::{lexer::Lexer, Parser, StringInput, Syntax, TsConfig};
 
     fn helper(
         file_name: &str,
@@ -233,7 +234,7 @@ mod tests {
                     import_assertions: true,
                     ..Default::default()
                 }),
-                JscTarget::Es2015,
+                EsVersion::Es2015,
                 (&*fm).into(),
                 Some(&comments),
             );
